@@ -4,6 +4,7 @@
 
 from event import Signal
 from copy import copy
+import os.path
 import pysndfile
 import numpy
 
@@ -91,25 +92,28 @@ class Sound(object):
             self.frames = numpy.array([])
             self.samplerate = 44100
             self._saved_revision = None
+            self._format = pysndfile.formatinfo()
         else:
+            filename = os.path.expanduser(filename)
             f = pysndfile.sndfile(filename)
             nframes = f.get_nframes()
             self.frames = f.read_frames(nframes)
             self.samplerate = f.get_samplerate()
+            self._format = f._format
             f.close()
             self._saved_revision = self.history.revision()
 
     def numchan(self):
         return self.frames.ndim
 
-    def save(self, format=pysndfile.formatinfo()):
-        self.save_as(self.filename, format)
+    def save(self):
+        self.save_as(self.filename)
 
-    def save_as(self, filename, format=pysndfile.formatinfo()):
+    def save_as(self, filename):
         if filename is None:
             raise Exception("No filename")
         f = pysndfile.sndfile(filename, mode='write',
-                              format=format,
+                              format=self._format,
                               channels=self.numchan(),
                               samplerate=self.samplerate)
         f.write_frames(self.frames)
@@ -437,6 +441,18 @@ def testSound():
     assert abs((snd.frames - snd2.frames).flatten().max()) == 0
     os.remove(outfile)
 
+    # Preserve file format when saving
+    snd = Sound("../sounds/test3.wav")
+    outfile = "/tmp/test3.wav"
+    snd.save_as(outfile)
+    snd2 = Sound(outfile)
+    assert snd2._format.type == 'wavex'
+    assert snd2._format.encoding == 'pcm24'
+    assert snd2._format.endianness == 'file'
+    assert snd.samplerate == 48000
+    os.remove(outfile)
+    
+
     # test mix_channels
     #
     # stereo to mono
@@ -614,7 +630,17 @@ def testSound():
         print "OK"
     else:
         assert False
-        
+
+    # expand user symbol
+    import mock
+    def fake_sndfile(filename):
+        assert '~' not in filename
+        return mock.Fake()
+    sndfile = pysndfile.sndfile
+    pysndfile.sndfile = fake_sndfile
+    Sound("~/sound.wav")
+    pysndfile.sndfile = sndfile
+
 if __name__ == '__main__':
     testAction()
     testSound()
